//
// Copyright 2023 Wultra s.r.o.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions
// and limitations under the License.
//

package com.wultra.android.malwarelytics.reactnative

/**
 * Interface that's used in `malwarelytics.gradle` to build a Smart Protection UI configuration.
 */
interface IMalwarelyticsUiConfig {
    val theme: Int?
    val notificationSmallIcon: Int?
    val notificationChannelId: String?
    val screenDeleteIcon: Int?
    val screenSettingsIcon: Int?
}

/**
 * Get configuration generated in `malwarelytics.gradle` script.
 * @param baseObject Java object that is used
 */
fun getMalwarelyticsUiConfig(javaPackagePath: String): IMalwarelyticsUiConfig {
    return try {
        Class.forName("$javaPackagePath.MalwarelyticsUiConfig").newInstance() as IMalwarelyticsUiConfig
    } catch (t: Throwable) {
        object: IMalwarelyticsUiConfig {
            override val theme: Int?
                get() = null
            override val notificationSmallIcon: Int?
                get() = null
            override val notificationChannelId: String?
                get() = null
            override val screenDeleteIcon: Int?
                get() = null
            override val screenSettingsIcon: Int?
                get() = null
        }
    }

}
