import type { NativeModule } from 'react-native';
import type { EventType } from './EventHelper';
import type { MalwarelyticsInitializationResult, MalwarelyticsState } from '../Malwarelytics';
import type { MalwarelyticsAppleDetectableApp, MalwarelyticsConfig } from '../MalwarelyticsConfig';
import { RaspEventType } from './RaspEvent';
import { SmartProtectionResult } from '../model/antivirus/SmartProtectionResult';
import { ApkThreat } from 'src/model/antivirus/ApkThreat';
import { ApkInfo } from 'src/model/antivirus/Apk';
import { UpdateInfo } from 'src/model/antivirus/update/UpdateInfo';
/**
 * Simple object containing module's state and the result.
 */
export interface StateWithResult {
    readonly state: MalwarelyticsState;
    readonly result?: MalwarelyticsInitializationResult;
}
/**
 * Native interface, implemented in Swift / Kotlin.
 */
export interface MalwarelyticsModuleIfc extends NativeModule {
    initialize(config: MalwarelyticsConfig): Promise<MalwarelyticsInitializationResult>;
    shutdown(clearAvUserId: boolean): Promise<void>;
    getState(): Promise<StateWithResult>;
    getKnownDetectableApps(): Promise<MalwarelyticsAppleDetectableApp[]>;
    getSupportedEvents(): Promise<Array<EventType>>;
    setClientId(clientId?: string): Promise<void>;
    setDeviceId(deviceId?: string): Promise<void>;
    getAvUserId(): Promise<string | undefined>;
    getRaspInfo(message: RaspEventType): Promise<any>;
    isAntivirusEnabled(): Promise<boolean>;
    setAntivirusLocalization(languageCode: string | undefined): Promise<void>;
    getAntivirusLocalization(): Promise<string | undefined>;
    triggerSmartProtection(performOnlineUpdate: boolean): Promise<SmartProtectionResult>;
    isSmartProtectionTriggered(): Promise<boolean>;
    getThreatList(): Promise<ApkThreat[]>;
    getApkInfo(packageName: string): Promise<ApkInfo | undefined>;
    getLastUpdateInfo(): Promise<UpdateInfo>;
}
/**
 * Instance of Native interface
 */
export declare const MalwarelyticsModule: MalwarelyticsModuleIfc;
/**
 * Wrap call to native interface and handle all possible exceptions.
 * @param module Module to use.
 * @param action Action to execute with module.
 * @returns Promise returned from the action.
 */
export declare function wrapNativeCall<T, M>(module: M, action: (module: M) => Promise<T>): Promise<T>;
//# sourceMappingURL=MalwarelyticsModule.d.ts.map