//
// Copyright 2023 Wultra s.r.o.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions
// and limitations under the License.
//

/** 
 * Data that describes Android APK. 
 */
export interface Apk {
    /**
     * Package name (Application ID) of the app.
     */
    packageName: string;
    /**
     * SHA-1 hash of the app's signature. The signature hash is optional but recommended to use.
     */
    signatureHash?: string;
}

/**
 * Information about Android APK.
 */
export interface ApkInfo {
    /**
     * Application name as displayed in the system.
     */
    readonly label: String;
    /**
     * Base64 encode PNG icon in the original size.
     * You can use it in html as `<img src="data:image/jpeg;base64,${apkInfo.icon}" width="96" />`
     */
    readonly icon?: String;
}