/**
 * Info about updates.
 *
 * The update info contains data about last successes and failures for each [UpdateType].
 */
export interface UpdateInfo {
    /** 
      * Map of success info data for each @see UpdateType.
      * Only updates with @see UpdateResult.SUCCESS are returned here. 
      */
    readonly successfulUpdates: Map<UpdateType, UpdateInfoSuccess>,
    /**
     * Map of failure info data for each @see UpdateType.
     * Info about updates with results @see UpdateResult.FAILURE and @see UpdateResult.PARTIAL_SUCCESS is returned here.
     */
    readonly failedUpdates: Map<UpdateType, UpdateInfoFailure>
}

/** Type of update. */
export enum UpdateType {
    /** Updating only a selection of apps. Happens for example when new app is installed or an app is updated. */
    PARTIAL = "PARTIAL",
    /** Updating all apps. */
    FULL = "FULL"
}

/** Info about the last successful update. */
export interface UpdateInfoSuccess {
    /** Unix timestamp of the last successful update. */
    readonly lastSuccessTimestamp?: number;
    /** Number of apps that were checked in the last successful update. */
    readonly lastSuccessCheckCount: number;
    /** Number of apps that had suggestions updated in the last successful update. */
    readonly lastSuccessUpdatedCount: number;
}

/** Info about the last failed update. */
export interface UpdateInfoFailure {
    /** Unix timestamp of the last failed update. */
    readonly lastFailureTimestamp?: number;
    /** Reason for the last update failure. */
    readonly lastFailureReason?: string;
}

