//
// Copyright 2023 Wultra s.r.o.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions
// and limitations under the License.
//

/** Screen sharing detection data. */
export interface ScreenSharingInfo {
    /**
     * Apple: Screen is captured
     * Android: Screen is shared
     */
    readonly isScreenShared: boolean
    /**
     * Android: Number of displays
     */
    readonly numberOfDisplays?: number
    /** 
     * Android: Transient data containing information about detected transient changes. 
     */
    readonly transientData: TransientScreenSharingData;
    /** 
     * Android: Whether the detection result is problematic for the app. 
     */
    readonly isProblematic: boolean;
    /** 
     * Android: Whether the detection result indicates a transient change. 
     */
    readonly isTransientChange: boolean;
}

/** Android: Obtained transient data. */
export interface TransientScreenSharingData {
    /** Whether an added display has just been detected. */
    readonly displayAdded: boolean;
    /** Whether a removed display has just been detected. */
    readonly displayRemoved: boolean;
}