//
// Copyright 2023 Wultra s.r.o.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions
// and limitations under the License.
//

export interface SystemIntegrityInfo {
    /**
     * Apple: true if device contains jailbreak.
     */
    readonly isJailbroken: boolean
    /**
     * Android: true if device is rooted.
     */
    readonly isRooted: boolean;
    /**
     * Android: Additional information about detected root.
     */
    readonly rootInfo?: RootDetectionInfo;
}

/** Root detection data. */
export interface RootDetectionInfo {
    /**
     * Android: true if root is cloaked.
     */
    readonly isRootCloaked: boolean;
    /**
     * Android specific.
     */
    readonly rootDetectionProofs: [RootDetectionProof];
    /**
     * Android specific.
     */
    readonly rootDetectionConfidence: number;
    /**
     * Android specific.
     */
    readonly rootCloakDetectionConfidence: number;    
}

export type RootDetectionProof = "RDP_01" | "RDP_02" | "RDP_03" | "RDP_04" | "RDP_05" | "RDP_06" | "RDP_07" | "RDP_08" | "RDP_09" | "RDP_10" | "RDP_11" | "RDP_12";
